Camera2DMode

Enum Camera2DMode 

pub enum Camera2DMode {
    Follow,
    Move,
}
How the camera should behave.

Variants



Follow

Follows the target if the target is too far away. This is usual behavior in 2D games where the player can move in the center of the image whithout moveing the camera. The camera only moves and follows if the player is is too far away from the center.



Move

Linear move to the target.