pub enum ModifyRangeResult {
Ok,
StartLimitReached {
low_limit: f32,
value: f32,
},
EndLimitReached {
high_limit: f32,
value: f32,
},
}Expand description
The result of modifying a range. It is Ok if the value is within the range, StartLimitReached if the value is below the range, and EndLimitReached if the value is above the range.
Variants