pub enum Camera2DMode {
Follow,
Move,
}Expand description
How the camera should behave.
Variants
Follow
Follows the target if the target is too far away. This is usual behavior in 2D games where the player can move in the center of the image whithout moveing the camera. The camera only moves and follows if the player is is too far away from the center.
Move
Linear move to the target.